@@ -33,9 +33,9 @@ class Deskewer():
         return edge_image
 
     def deskew(self, image):
-        image = image[:image.shape[0]//2]
+        edge_image = image[:image.shape[0]//2]
 
-        edge_image = self.edge_detection(image)       
+        edge_image = self.edge_detection(edge_image)       
         edge_height, edge_width = edge_image.shape[:2]
         edge_height_half, edge_width_half = edge_height / 2, edge_width / 2
 
